======
TOPAZ
======

TOPAZ (TOol for Plotting Aurora's Metals) is a Python package 

Installation
------------
TOPAZ can be installed with pip:

``pip install topaz``

The developement version is avaliable by cloning this repository:

::

  git clone https://github.com/abatten/topaz
  cd topaz
  pip install -e .
